@@ -3,8 +3,8 @@ import requests
 import hashlib
 from . import api
 
-def get_credentials(api_key, schema='prod'):
-    response = requests.get(f"{api.get(schema)}/api/db_credentials", headers={'key': api_key}).json()
+def get_credentials(api_key, api_schema, db_schema):
+    response = requests.get(f"{api_schema}/api/db_credentials", headers={'key': api_key, 'db':db_schema}).json()
     if response['msg'] == 'success':
         return response['data']
     else:
@@ -12,8 +12,8 @@ def get_credentials(api_key, schema='prod'):
         return None
 
 
-def get(api_key, schema, buffered=True, dictionary=False):
-    credentials = get_credentials(api_key=api_key, schema=schema)
+def get(api_key, api_schema=api.prod, db_schema=None,  buffered=True, dictionary=False):
+    credentials = get_credentials(api_key=api_key, api_schema=api_schema, db_schema=db_schema)
     if not credentials:
         return None, None
     cnx = mysql.connector.connect(
